---
layout: post
title: Adventures in setting up a T60 with a modern OS — Battery, driver issues and HDD
---

![RAM](/assets/t60-ram-loc.jpg){:class="img-responsive"}

## Battery
The new battery for my T60 has finally arrived! I was very happy about the fact that it seems to look basically identical to the original battery and about it being quite powerful. From my, admittedly rather short testing, it seems that it will last around 2 - 3 hours when fully charged, which is plenty. I will be keeping the battery that came with the laptop as a spare, should I ever need one, though. I was surprised to see how light it was in comparison to the original Lenovo battery, even though it has much more capacity; but I won't complain about that.  
It does, as already expected, stick out slightly from the back of the laptop, but this isn't annoying in any way.

Checking the output of `sudo tlp-stat --battery` again shows that the capacity of the old battery has dropped down to 34%.

There were reports of the power supply getting hotter when using this battery, but I have honestly not noticed any of that. The power supply of these machines tend to get quite warm anyway; it's a common enough problem, but the power supplies' temperature tends to be still within tolerable levels.

I was also quite surprised about its relatively quick arrival; I had ordered it at a rather prominent online store but was told that it was going to arrive on April 22nd, due to the current SARS-CoV-2019 outbreak. The new power supply that I have ordered elsewhere, however, has not yet arrived, despite me being told that it was going to be arriving today — but honestly, having the battery is more important anyway.

## Drivers
I had previously had some issues with my video drivers and it was entirely my fault; Manjaro has a great out-of-the-box support for the majority of video cards, but because I have issues I thought I would check out `mhwd` (Manjaro Hardware Detection) and see if there were any other drivers for me to install — and there were. Aside from the one that had already been installed, namely `video-linux` there were a bunch of others that could be installed as well: —

```
> 0000:00:02.0 (0300:8086:27a2) Display controller Intel Corporation:
--------------------------------------------------------------------------------
                  NAME               VERSION          FREEDRIVER           TYPE
--------------------------------------------------------------------------------
           video-linux            2018.05.04                true            PCI
     video-modesetting            2020.01.13                true            PCI
            video-vesa            2017.03.12                true            PCI
```

 Unfortunately for me, however, those that were _not_ installed seem to have been drivers that don't work very well with my video card, if at all. Thus, I've been experiencing very slow and laggy programs, more so than I had hoped. Luckily, I figured out the problem and by uninstalling the "_bad"_ drivers I managed to fix it. The result of this is that I can now actually browse the web very well without any lagging and even YouTube videos are playing nicely now.

Additionally, this solves the problem of the display being quite _wonky_ after suspension; it used to have a strange y-axis offset whenever it would awaken from suspension which resulted in a black bar at the bottom of the screen and all programs being displayed "too high".

### Temperature improvements due to drivers
Another side-effect of installing the correct drivers is that the temperature of the machine has dropped quite significantly. Running the `sensors` command now yields the following output: —

```
cpitz-acpi-0
Adapter: ACPI interface
temp1:        +43.0°C  (crit = +127.0°C)
temp2:        +40.0°C  (crit = +99.0°C)

coretemp-isa-0000
Adapter: ISA adapter
Core 0:       +40.0°C  (high = +100.0°C, crit = +100.0°C)
Core 1:       +40.0°C  (high = +100.0°C, crit = +100.0°C)
```

These temperatures are from regular usage, i. e. browsing the web, editing my blog etc. Earlier, however, these temperatures tended to quite quickly exceed 60°C and the idle temperature was at around 50 to 55°C. This, in return, has the additional benefit of the fans having to spin less and thus improving battery life. I have even seen the temperatures drop below 40°C, which I found very surprising.

I honestly did not think that installing the wrong drivers could be so detrimental to the performance of one's PC, but I am glad that, using the correct drivers, I am finally able to use this machine even better than I was before.

## Why is the RAM here?
As I had mentioned in the previous post, I was unsure as to which kinds of screws were used for holding the laptop together, as I was unable to unscrew them using the screwdrivers I had at home; and, as it turns out, it _was_ a Phillips head, just an even smaller one than the one I had at home, it seems. However, I was finally able to find out where the RAM is located — and I was quite honestly very surprised about its location, because it's actually located underneath the TouchPad! Thus, to get to it, you will need to unscrew four screws on the back of the laptop and actually take off the palm rest — and be careful while doing so, as the cable attaching the touchpad to the interior of the laptop can quite easily be ripped off.
My main question, however, is why the RAM is located in such an awkward place; I'm sure it could've been possible to place it somewhere that wouldn't require you to basically take apart the palm rest.
Regardless of that, I have yet to receive my new RAM sticks; they may arrive today and if they do, I will create a new blog post about them in particular.

## More HDD information
I was also curious to find out more about the hard drive installed on this machine and installed `smartmontools` which is used to show an HDDs information if it uses S.M.A.R.T. `smartmontools` can be found in the official Manjaro `extra` repositories or in the AUR. 
Well, as it turns out, this HDD is actually nigh collapse… and I don't think I should be too surprised about that. The output of `sudo smartctl -a /dev/sda` (wherein `/dev/sda` is my HDD) shows how badly it's doing:

```
D# ATTRIBUTE_NAME          VALUE WORST THRESH TYPE      RAW_VALUE
  1 Raw_Read_Error_Rate     100   100   062    Pre-fail     0
  2 Throughput_Performance  105   105   040    Pre-fail    4577
  3 Spin_Up_Time            253   253   033    Pre-fail     0
  4 Start_Stop_Count        100   100   000    Old_age     991
  5 Reallocated_Sector_Ct   100   100   005    Pre-fail     0
  7 Seek_Error_Rate         100   100   067    Pre-fail     0
  8 Seek_Time_Performance   122   122   040    Pre-fail     39
  9 Power_On_Hours          094   094   000    Old_age     2921
 10 Spin_Retry_Count        100   100   060    Pre-fail     0
 12 Power_Cycle_Count       100   100   000    Old_age     921
191 G-Sense_Error_Rate      100   100   000    Old_age      0
192 Power-Off_Retract_Count 100   100   000    Old_age  1626996769
193 Load_Cycle_Count        089   089   000    Old_age    114263
194 Temperature_Celsius     157   157   000    Old_age 35 (Min/Max 1/46)
196 Reallocated_Event_Count 100   100   000    Old_age       0
197 Current_Pending_Sector  100   100   000    Old_age       0
198 Offline_Uncorrectable   100   100   000    Old_age       0
199 UDMA_CRC_Error_Count    200   253   000    Old_age       0
```

There is a large amount of `Old_age` or `Pre-fail` types and nothing seems to be okay; this may actually be on of the reasons for this laptop being so slow at times, despite the processor not being too terrible. And while I'd hate having to set up everything again, I don't think I will be getting around doing that because this hard drive is quite clearly going to die _very_ soon.
And because I thought I might as well go _all out_ if I do, I have ordered a 128 GB SSD online that will hopefully arrive on Friday. I have never actually used an SSD in any of my computers, but it's quite noticeable that this hard drive has seen its best days already.
I also believe this may increase the performance because of the low amount of RAM; as this laptop only supports 3 GB of RAM, it will frequently have to use its swap drive and if that is running on this very old and slow HDD, I can see how it would make the laptop basically unusable.
Although, I must be honest, it does surprise me slightly; the `Power_On_Hours` is only at `2921` which is a _very_ low value; I'm not quite sure why the HDD would be near failure after such a short amount of time.
